@@ -15,7 +15,7 @@ class FileSystemFacade:
     """
     def determine_migration_directory_for_service(self,
                                                   migration_directory_root: str,
-                                                  service_name: str):
+                                                  service_name: str) -> str:
         """
         Generates the migration directory for a particular service.
 
@@ -24,37 +24,46 @@ class FileSystemFacade:
         """
         return os.path.join(migration_directory_root, service_name)
 
-    def migration_dir_exists(self, dir_):
+    def does_directory_exist(self, directory: str) -> bool:
         """
         Determines whether a directory exists.
 
         :param dir_: The directory path to check.
         :return: True if the given directory path is a directory and exists.
         """
-        return os.path.isdir(dir_)
+        return os.path.isdir(directory)
 
-    def does_file_exist(self,
-                        migration_directory: str,
-                        file_name: str):
+    def does_file_exist_in_directory(self,
+                                     directory: str,
+                                     file_name: str) -> bool:
         """
-        Checks whether the migrated data for a given single file migration
-        service exists in the migration directory and can be restored.
+        Determines whether a file with the given name exists in a directory
 
-        :param service: The service to verify data has been migrated for.
-        :return: True if there is migrated data for a given service
+        :param directory: The directory to check.
+        :param file_name: The file to check.
+        :return: True if the file exists in the given directory.
         """
-        path = os.path.join(migration_directory, file_name)
-        return os.path.isfile(path)
+        path = os.path.join(directory, file_name)
+        return self.does_file_exist(path)
 
-    def remove_dir(self, dir_):
+    def does_file_exist(self, file_path: str) -> bool:
+        """
+        Determines whether a file exists on disk.
+
+        :param file_path: The path to check.
+        :return: True if the file exists.
+        """
+        return os.path.isfile(file_path)
+
+    def remove_directory(self, directory: str):
         """
         Deletes the given directory and its children.
 
         :param dir_: The directory to remove.
         :return: None.
         """
-        if os.path.isdir(dir_):
-            shutil.rmtree(dir_, onerror=self.__on_error_remove_readonly_and_retry)
+        if os.path.isdir(directory):
+            shutil.rmtree(directory, onerror=self.__on_error_remove_readonly_and_retry)
 
     def migrate_singlefile(self,
                            migration_directory_root: str,
@@ -72,7 +81,7 @@ class FileSystemFacade:
         root = migration_directory_root
         migration_dir = self.determine_migration_directory_for_service(root, service_name)
         if action == MigrationAction.CAPTURE:
-            self.remove_dir(migration_dir)
+            self.remove_directory(migration_dir)
             os.mkdir(migration_dir)
             singlefile_full_path = os.path.join(
                 single_file_source_directory,
@@ -83,14 +92,14 @@ class FileSystemFacade:
             singlefile_full_path = os.path.join(migration_dir, single_file_name)
             shutil.copy(singlefile_full_path, single_file_source_directory)
 
-    def capture_singlefile(self,
-                           migration_directory_root: str,
-                           service_name: str,
-                           restore_directory: str,
-                           file: str):
+    def capture_single_file(self,
+                            migration_directory_root: str,
+                            service_name: str,
+                            restore_directory: str,
+                            file: str):
         root = migration_directory_root
         migration_dir = self.determine_migration_directory_for_service(root, service_name)
-        self.remove_dir(migration_dir)
+        self.remove_directory(migration_dir)
         os.mkdir(migration_dir)
         singlefile_full_path = os.path.join(
             restore_directory,
@@ -98,11 +107,11 @@ class FileSystemFacade:
         )
         shutil.copy(singlefile_full_path, migration_dir)
 
-    def restore_singlefile(self,
-                           migration_directory_root: str,
-                           service_name: str,
-                           restore_directory: str,
-                           file: str) -> None:
+    def restore_single_file(self,
+                            migration_directory_root: str,
+                            service_name: str,
+                            restore_directory: str,
+                            file: str):
         root = migration_directory_root
         migration_dir = self.determine_migration_directory_for_service(root, service_name)
         singlefile_full_path = os.path.join(migration_dir, file)
@@ -120,7 +129,7 @@ class FileSystemFacade:
             return json.load(json_file)
 
     @staticmethod
-    def copy_file(from_directory: str, to_directory: str, file_name: str) -> None:
+    def copy_file(from_directory: str, to_directory: str, file_name: str):
         """
         Copy an entire directory from one location to another.
 
@@ -147,7 +156,7 @@ class FileSystemFacade:
         if not os.path.exists(from_directory):
             raise MigrationError("No data found at: '%s'" % from_directory)
 
-        self.remove_dir(to_directory)
+        self.remove_directory(to_directory)
         shutil.copytree(from_directory, to_directory)
 
     def copy_directory_if_exists(self, from_directory: str, to_directory: str, force: bool) -> bool:
